import { makeStyles } from "@material-ui/core/styles";
import { useDispatch } from "react-redux";
import CloseIcon from '@mui/icons-material/Close';
import MenuItem from '@mui/material/MenuItem';
import ListItemText from '@mui/material/ListItemText';

import { firstLetter,slicedWord } from "../../../../../../helpers";
import { TMessage } from "../../../../../../typescript/redux/messages/types";
import { asyncGetChatById } from '../../../../../../redux/chat/operations'
import { actionRightIsOpen, actionScrollChat, actionOpenPinned } from '../../../../../../redux/control/action'

const useStyles = makeStyles({   
  replyTop : {
    position: 'absolute',
    left: 0,
    top: '-7vh',
    height: '6vh',
    width: '100%',
    borderRadius: 8,
    display: 'flex',
    flexWrap: 'nowrap',
    alignContent: 'center',
    alignItems: 'center',
    color: '#6b6b6b',
    border:'solid 2px rgb(41, 139, 231)',
    backgroundColor: '#ffffff',
    padding: 0,
    zIndex:2,
  },
  replyIconClose: {
    cursor: 'pointer',
    margin:'0px 7px',
    '&:hover': {
      color:'#f02a2a',
      transform: 'rotate(180deg)',
      transition: 'all 250ms ease-out ',
    }
  },
  replyListWrapper: {
    width: '100%',
  },
  replyColumn: {
    height: '80%',
    width: 2,
    backgroundColor: '#00aeff',
  }, 
});

interface IForwardBar {
  companionId: string,
  isForward:TMessage,
  handleCloseForward: () => void,
  handleScrollToTheMessage: (_id: string) => void,
  setIsForward: React.Dispatch<React.SetStateAction<TMessage | undefined>>,
}

const ForwardBar = ({ companionId,isForward, handleCloseForward,handleScrollToTheMessage,setIsForward }: IForwardBar) => {
  const classes = useStyles();
  const dispatch = useDispatch()
  
  const handleScrollHereOrBack = () => {
    if (companionId === isForward.companionId) return handleScrollToTheMessage(isForward._id)
    setIsForward(undefined)
    dispatch(actionRightIsOpen(''))
    dispatch(actionOpenPinned(false))
    dispatch(asyncGetChatById(isForward.companionId))
    setTimeout(() => handleScrollToTheMessage(isForward._id), 2000)
  }
  
  return (
    <div className={classes.replyTop}>
      <CloseIcon onClick={handleCloseForward} className={classes.replyIconClose} />
      <div className={classes.replyColumn}></div>
        <ul className={classes.replyListWrapper}>
          <MenuItem onClick={handleScrollHereOrBack}>
            <ListItemText
              primary={`${firstLetter(isForward.name)}${slicedWord(isForward.name, 15, 1)} 
              ${firstLetter(isForward.lastName)}${slicedWord(isForward.lastName, 15, 1)}`}
              primaryTypographyProps={{ color: "#0379af",fontSize:16 }}
              secondary={`Type : ${isForward.type.toUpperCase()}`}
              secondaryTypographyProps={{ fontSize:16 }}/>          
          </MenuItem>
        </ul>
    </div>
  )
}

export default ForwardBar