import List from '@mui/material/List';
import { makeStyles } from '@material-ui/core'
import { useMemo } from 'react';

import AlertInfo from '../../../../../../reusableComponents/AlertInfo'
import ForwardItem from './ForwardItem'
import { TChats } from '../../../../../../../typescript/redux/chats/types';


const useStyles = makeStyles({
  list: {
    width: '100%',
    maxHeight: '63vh',
    overflowY: 'scroll',
  '&::-webkit-scrollbar': {
    width: '0.4em'
  },
  '&::-webkit-scrollbar-track': {
    boxShadow: 'inset 0 0 6px rgba(0,0,0,0.00)',
    webkitBoxShadow: 'inset 0 0 6px rgba(0,0,0,0.00)',
    backgroundColor: '#eceeec',
  },
  '&::-webkit-scrollbar-thumb': {
    backgroundColor: '#ccc8c8',
    },
  "&::-webkit-scrollbar-thumb:focus": {
    backgroundColor: "#959595",
          },
  "&::-webkit-scrollbar-thumb:active": {
    backgroundColor: "#959595",
    },
  },
})

interface IForwardList {
  value: string,
  chats:TChats,
  total: string,
  handleForwardTo: (companionId: string) => void,
}

const ForwardList = ({ value, chats, total,handleForwardTo }: IForwardList) => {
  const classes = useStyles()
  
  const filteredChatsMemo = useMemo((): TChats => {
    return chats.filter((el) => {
      const credentials = el.name + ' ' + el.lastName
      if (credentials.toLowerCase().includes(value.toLowerCase())) return el
      return undefined
    })
  }, [chats, value])

  return total !== '0' ? (<>
    <List className={classes.list} component="nav"
      aria-label="main mailbox folders">
      {filteredChatsMemo.length > 0 ?
        filteredChatsMemo.map(({ name, lastName, avatarUrl, color, online, companionId, number }) =>
          <ForwardItem key={number} name={name} lastName={lastName}
            avatarUrl={avatarUrl} color={color} online={online}
            companionId={companionId} handleForwardTo={handleForwardTo} />) :
        <AlertInfo name={`Can not find Chat by request: ${value}`} />}
    </List>
  </>) : <AlertInfo name='You do not have other Chats yet!' />
}

export default ForwardList