import { makeStyles } from "@material-ui/core/styles";
import CloseIcon from '@mui/icons-material/Close';
import MenuItem from '@mui/material/MenuItem';
import ListItemText from '@mui/material/ListItemText';

import { firstLetter,slicedWord } from "../../../../../../helpers";
import { TMessage } from "../../../../../../typescript/redux/messages/types";

const useStyles = makeStyles({   
  replyTop : {
    position: 'absolute',
    left: 0,
    top: '-7vh',
    height: '6vh',
    width: '100%',
    borderRadius: 8,
    display: 'flex',
    flexWrap: 'nowrap',
    alignContent: 'center',
    alignItems: 'center',
    color: '#6b6b6b',
    border:'solid 2px rgb(41, 139, 231)',
    backgroundColor: '#ffffff',
    padding: 0,
    zIndex:2,
  },
  replyIconClose: {
    cursor: 'pointer',
    margin:'0px 7px',
    '&:hover': {
      color:'#f02a2a',
      transform: 'rotate(180deg)',
      transition: 'all 250ms ease-out ',
    }
  },
  replyListWrapper: {
    width: '100%',
  },
  replyColumn: {
    height: '80%',
    width: 2,
    backgroundColor: '#00aeff',
  }, 
});

interface IReplyBar {
  isReply:TMessage,
  handleCloseReply: () => void,
  handleScrollToTheMessage:(_id:string) => void
}

const ReplyBar = ({ isReply, handleCloseReply,handleScrollToTheMessage }: IReplyBar) => {
  const classes = useStyles();
  
  return (
    <div className={classes.replyTop}>
      <CloseIcon onClick={handleCloseReply} className={classes.replyIconClose} />
      <div className={classes.replyColumn}></div>
        <ul className={classes.replyListWrapper}>
          <MenuItem onClick={() => handleScrollToTheMessage(isReply._id)}>
            <ListItemText
              primary={`${firstLetter(isReply.name)}${slicedWord(isReply.name, 15, 1)} 
              ${firstLetter(isReply.lastName)}${slicedWord(isReply.lastName, 15, 1)}`}
              primaryTypographyProps={{ color: "#0379af",fontSize:16 }}
              secondary={`Type : ${isReply.type.toUpperCase()}`}
              secondaryTypographyProps={{ fontSize:16 }}/>          
          </MenuItem>
        </ul>
    </div>
  )
}

export default ReplyBar